<?php
defined( 'ABSPATH' ) || exit;

class NCWM_Define {
    public function cartGroups() {
        return array(
            'api' => array(
                'shopify',
                'bigcommerce',
                'ecwid',
                '3dcart',
                'americommerce'
            ),
            'file' => array(
                'weebly',
                'volusion',
                'ekm',
                'adobebusinesscatalyst',
                'amazonstore'
            )
        );
    }

    public function getCartGroup($name) {
        $groups = $this->cartGroups();
        foreach ($groups as $group => $carts) {
            foreach ($carts as $cart) {
                if ($cart == $name) {
                    return $group;
                }
            }
        }
        return 'connector';
    }

    public function getCartConnectType($name) {
        $type = $this->getCartGroup($name);
        if ($type == 'api') {
            return 'API';
        } elseif ($type == 'file') {
            return 'Files Upload';
        } else {
            return 'KitConnect';
        }
    }

    public function formInfos() {
        return array(
            'shopify' => array(
                'api_key' => "API Key",
                'password' => "Password"
            ),
            'weebly' => array(
                'product' => 'Product(.csv)',
                'order' => 'Order(.csv)'
            ),
            'volusion' => array(
                'exchangeRates' => 'ExchangeRates.csv',
                'taxes' => 'Taxes.csv',
                'categories' => 'Categories.csv',
                'products' => 'Products.csv',
                'optionCategories' => 'OptionCategories.csv',
                'options' => 'Options.csv',
                'kits' => 'KITS.csv',
                'kitLinks' => 'KITLNKS.csv',
                'images' => 'ProductImages.csv',
                'customers' => 'Customers.csv',
                'orders' => 'Orders.csv',
                'orderDetails' => 'OrderDetails.csv',
                'reviews' => 'Reviews.csv'
            ),
            'ecwid' => array(
                'personal_collection_url' => 'Personal collection URL',
            ),
            'bigcommerce' => array(
                'api_path' => "API Path",
                'client_id' => "Client ID",
                'api_token' => "Access Token"
            ),
            '3dcart' => array(),
            'americommerce' => array(
                'access_token' => "Access Token",
            ),
            'ekm' => array(
                'category' => 'Category.csv',
                'product' => 'Product.csv',
                'customer' => 'Customer.csv',
                'order' => 'Order.csv'
            ),
            'adobebusinesscatalyst' => array(
                'product' => 'Products(.csv)',
                'customer' => 'Customers(.csv)',
                'order' => 'Orders(.csv)'
            ),
            'amazonstore' => array(
                'product' => 'Products',
                'order' => 'Orders'
            ),
        );
    }

    public function getFormFields($name) {
        $infos = $this->formInfos();
        return isset($infos[$name]) ? $infos[$name] : array();
    }

    public function cartInstructions() {
        return array(
            'shopify' => array(
                'placeholder' => "http://hostname.myshopify.com",
                'guide_url' => "https://next-cart.com/how-to-get-shopify-api-credentials/",
                'guide_text' => "How to get Shopify API credentials?"
            ),
            'bigcommerce' => array(
                'guide_url' => "https://next-cart.com/how-to-get-bigcommerce-api-credentials/",
                'guide_text' => "How to get BigCommerce API credentials?"
            ),
            '3dcart' => array(
                'placeholder' => "http://storeid.3dcart.net",
                'guide_url' => "https://next-cart.com/how-to-use-3dcart-rest-api/",
                'guide_text' => "How to set up 3dcart REST API?"
            ),
            'americommerce' => array(
                'placeholder' => "http://hostname.americommerce.com",
                'guide_url' => "https://next-cart.com/how-to-get-americommerce-api-credentials/",
                'guide_text' => "How to get AmeriCommerce REST API credentials?"
            ),
        );
    }

    public function getCartInstruction($name) {
        $default = array(
            'placeholder' => "http://yourstoredomain.com",
            'guide_url' => "https://next-cart.com/category/migration-guides/",
            'guide_text' => "How to get " . ucfirst($name) . " API credentials?"
        );
        $instructions = $this->cartInstructions();
        return isset($instructions[$name]) ? array_merge($default, $instructions[$name]) : $default;
    }

    public function allSourceTypes() {
        $single = '__source_cart_type__';
        $carts = array(
            'ubercart' => 'Ubercart',
//            'nopcommerce' => 'Nopcommerce',
            'volusion' => 'Volusion',
            'oscommerce' => 'OsCommerce',
            'virtuemart' => 'VirtueMart',
            'zencart' => 'ZenCart',
//            'interspire' => 'Interspire',
            'shopify' => 'Shopify',
            'bigcommerce' => 'BigCommerce',
//            'mivamerchant' => 'Miva Merchant',
            'woocommerce' => 'Woocommerce',
            'prestashop' => "Prestashop",
            'opencart' => 'Opencart',
//            '3dcart' => '3dCart',
//            'bigcartel' => 'Big Cartel',
            'amazonstore' => 'Amazon Store',
//            'yahoostore' => 'Yahoo Store/Aabaco',
            'jigoshop' => 'Jigoshop',
            'weebly' => 'Weebly',
//            'squarespace' => 'Squarespace',
            'magento' => 'Magento',
//            'pinnaclecart' => 'PinnacleCart',
            'wpecommerce' => 'WP e-Commerce',
            'cubecart' => "CubeCart",
            'oxideshop' => "OXID-eShop",
            'cscart' => "CS-Cart",
            'hikashop' => "Hikashop",
            'xcart' => "X-Cart",
//            'jshop' => "Jshop Server",
//            'wix' => 'Wix',
            'americommerce' => 'AmeriCommerce',
            'ecwid' => "Ecwid",
            'adobebusinesscatalyst' => "Adobe Business Catalyst",
            'ekm' => "Ekm",
            'xtcommerce' => 'xt:Commerce',
            '3dcart' => '3dCart',
            'mijoshop' => 'MijoShop',
            'abantecart' => 'AbanteCart',
            'loadedcommerce' => 'Loaded Commerce'
        );
        ksort($carts);
        return isset($carts[$single]) ? array($single => $carts[$single]) : $carts;
    }
}
