<?php
defined( 'ABSPATH' ) || exit;

class NCWM_Main {
    
    const APP_URL = 'https://demo.next-cart.com/app/woocommerce/';
    const SITE_URL = 'https://next-cart.com/';
    
    protected static $_instance = null;


    public static function instance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }


    public function __construct() {
        $this->includes();
        $this->init_hooks();
    }
    
    private function includes() {
        include_once NCWM_PLUGIN_DIR . '/includes/core-functions.php';
        include_once NCWM_PLUGIN_DIR . '/includes/display.php';
        include_once NCWM_PLUGIN_DIR . '/includes/carts/define.php';
    }
    
    private function init_hooks() {
        add_action('admin_menu', array($this, 'admin_menu'));
        register_activation_hook(NCWM_PLUGIN_FILE, array($this, 'install'));
        add_action('wp_ajax_ncwm_migration', array('NCWM_Display', 'displayAjax'));
        add_action('admin_enqueue_scripts', array($this, 'admin_styles'));
        add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));
    }
    
    public function install() {
        $register_url = self::APP_URL . 'install.php';
        $post_data = array(
            'store' => get_site_url()
        );
        $args = array(
            'body' => $post_data,
            'timeout' => '30',
            'redirection' => '5',
            'httpversion' => '1.0',
            'blocking' => true,
            'headers' => array(),
            'cookies' => array()
        );
        $response = wp_remote_post($register_url, $args);
    }

    /**
     * Add menu items.
     */
    public function admin_menu() {
        add_menu_page('Next-Cart Migration', 'Next-Cart Migration', 'manage_options', 'nextcart-migration', array('NCWM_Display', 'loadMigrationPage'), NCWM_PLUGIN_URL . '/assets/images/logo16.png', '56.5');

        add_submenu_page('nextcart-migration', 'How It Works', 'How It Works', 'manage_options', 'nextcart-how-it-works', array('NCWM_Display', 'loadHowItWorks'));
        
        add_submenu_page('nextcart-migration', 'Extra Services', 'Extra Services', 'manage_options', 'nextcart-extra-services', array('NCWM_Display', 'loadExtraServices'));
        
        add_submenu_page('nextcart-migration', 'Pro License', 'Pro License', 'manage_options', 'nextcart-unlimited-migration', array('NCWM_Display', 'loadOfficialMigration'));
    }
    
    /**
     * Enqueue styles.
     */
    public function admin_styles() {
        if ( 'toplevel_page_nextcart-migration' === get_current_screen()->id ) {
            wp_enqueue_style('ncwm-bootstrap-css', NCWM_PLUGIN_URL . '/assets/css/bootstrap.min.css', array(), NCWM_PLUGIN_VERSION);
            wp_enqueue_style('ncwm-bootstrap-select-css', NCWM_PLUGIN_URL . '/assets/css/bootstrap-select.min.css', array(), NCWM_PLUGIN_VERSION);
            wp_enqueue_style('ncwm-style-css', NCWM_PLUGIN_URL . '/assets/css/style.css', array(), NCWM_PLUGIN_VERSION);
        }
        if (in_array(get_current_screen()->id, array('next-cart-migration_page_nextcart-how-it-works', 'next-cart-migration_page_nextcart-extra-services', 'next-cart-migration_page_nextcart-unlimited-migration'))) {
            wp_enqueue_style('ncwm-submenus-style-css', NCWM_PLUGIN_URL . '/assets/css/sub-menus.css', array(), NCWM_PLUGIN_VERSION);
        }
    }
    
    /**
     * Enqueue scripts.
     */
    public function admin_scripts() {
        if ( 'toplevel_page_nextcart-migration' === get_current_screen()->id ) {
            wp_enqueue_script('ncwm-popper-js', NCWM_PLUGIN_URL . '/assets/js/popper.min.js', array('jquery'), NCWM_PLUGIN_VERSION);
            wp_enqueue_script('ncwm-bootstrap-js', NCWM_PLUGIN_URL . '/assets/js/bootstrap.min.js', array('jquery'), NCWM_PLUGIN_VERSION);
            wp_enqueue_script('ncwm-bootstrap-select-js', NCWM_PLUGIN_URL . '/assets/js/bootstrap-select.min.js', array('jquery'), NCWM_PLUGIN_VERSION);
            wp_register_script('ncwm-cart-js', NCWM_PLUGIN_URL . '/assets/js/cart.min.js', array('jquery'), NCWM_PLUGIN_VERSION);
            wp_localize_script('ncwm-cart-js', 'ncwm_ajax_request_params', array('ajax_wp_url' => admin_url('admin-ajax.php'), 'ajax_app_url' => self::APP_URL . '?store=' . get_site_url()));
            wp_enqueue_script('ncwm-cart-js');
        }
    }
    
}
//add_filter('current_screen', 'my_current_screen' );
// 
//function my_current_screen($screen) {
//    if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) return $screen;
//    print_r($screen);
//    return $screen;
//}
NCWM_Main::instance();
